import React, {Fragment} from 'react';
import ReactDOM from 'react-dom';
import {Provider} from 'react-redux';
import {ThemeProvider} from 'styled-components';
import {BrowserRouter, Switch, Route, matchPath} from 'react-router-dom';

import createStore from '@ibibo/create-redux-store';
import {defaultTheme} from '@ibibo/build-theme';
import {GlobalStyles} from '@ibibo/global-style';
import Header from '@ibibo/header';
import Footer from '@ibibo/footer';
import commonHelmetJson from '@ibibo/common-helmet-json';
import {Helmet} from 'react-helmet';

// Common user widget integeration
// Ping did mount integeration
// Component did catch error tracking
// Modal support

const App = ({routes, store}) => {
  let hideHeader = false;
  let hideFooter = false;
  const RouteComponent = props => {
    const {location} = props;
    const {pathname} = location;
    routes.some(route => {
      const matchObj = matchPath(pathname, route);
      if (matchObj) {
        const {showHeader = true, showFooter = true} = route;
        hideHeader = !showHeader;
        hideFooter = !showFooter;
      }
      return matchObj;
    });
    return (
      <Fragment>
        {(!hideHeader && <Header location={window.location} />) || null}
        <Switch>
          {routes.map(route => (
            <Route {...route} />
          ))}
        </Switch>
        {(!hideFooter && <Footer />) || null}
      </Fragment>
    );
  };
  return (
    <ThemeProvider theme={defaultTheme}>
      <Helmet {...commonHelmetJson} />
      <Provider store={store}>
        <GlobalStyles />
        <BrowserRouter>
          <Route component={RouteComponent} />
        </BrowserRouter>
      </Provider>
    </ThemeProvider>
  );
};

export default function mountReactApp({routes, reducers, initialState = window.__initial_state__}) {
  const store = createStore({reducers, initialState});
  const urlPath = window.location.pathname;
  const searchString = window.location.search;
  routes.some(route => {
    const matchObj = matchPath(urlPath, route);
    if (matchObj) {
      const {params = {}} = matchObj;
      const {populateStoreFromUrl = () => {}} = route;
      populateStoreFromUrl({params, searchString}, store.dispatch);
    }
    return matchObj;
  });
  ReactDOM.hydrate(<App routes={routes} store={store} />, document.getElementById('root'));
  window.pageSeen('TTI');
}
