import React, {Component} from 'react';
import {Provider} from 'react-redux';
import {ThemeProvider} from 'styled-components';
import {defaultTheme} from '@ibibo/build-theme';
import {GlobalStyles} from '@ibibo/global-style';
import {StaticRouter, Switch, Route} from 'react-router-dom';
import Header from '@ibibo/header';
import Footer from '@ibibo/footer';
import commonHelmetJson from '@ibibo/common-helmet-json';
import {Helmet} from 'react-helmet';

const App: React.FC = ({store, routes, url, footerParam, hideHeader, hideFooter}) => {
  return (
    <ThemeProvider theme={defaultTheme}>
      <Helmet {...commonHelmetJson} />
      <Provider store={store}>
        <GlobalStyles />
        <StaticRouter location={url}>
          {(!hideHeader && <Header location={{pathname: url}} />) || null}
          <Switch>
            {routes.map(route => (
              <Route {...route} />
            ))}
          </Switch>
          {(!hideFooter && <Footer {...footerParam} />) || null}
        </StaticRouter>
      </Provider>
    </ThemeProvider>
  );
};

export default App;
